@@ -4,12 +4,22 @@
 #include <elf.h>
 #include "ltrace.h"
 
+#if ELFSIZE == 64
+#define Elf_Sym  Elf64_Sym
+#define Elf_Ehdr Elf64_Ehdr
+#define Elf_Shdr Elf64_Shdr
+#else
+#define Elf_Sym  Elf32_Sym
+#define Elf_Ehdr Elf32_Ehdr
+#define Elf_Shdr Elf32_Shdr
+#endif
+
 struct ltelf {
 	int		fd;
 	void*		maddr;
-	Elf32_Ehdr*	ehdr;
+	Elf_Ehdr*	ehdr;
 	char*		strtab;
-	Elf32_Sym*	symtab;
+	Elf_Sym*	symtab;
 	int		symtab_len;
 };
 
