@@ -10,11 +10,13 @@
 #include <sys/param.h>
 #include <signal.h>
 #include <sys/wait.h>
+#include <sys/ioctl.h>
 
 #include "ltrace.h"
 #include "output.h"
 #include "read_config_file.h"
 #include "options.h"
+#include "debug.h"
 
 #ifndef SYSCONFDIR
 #define SYSCONFDIR "/etc"
@@ -42,9 +44,7 @@ signal_alarm(int sig) {
 			}
 			tmp2 = tmp2->next;
 		}
-		if (opt_d>1) {
-			output_line(0,"Sending SIGSTOP to process %u\n",tmp->pid);
-		}
+		debug(2,"Sending SIGSTOP to process %u\n",tmp->pid);
 		kill(tmp->pid, SIGSTOP);
 		tmp = tmp->next;
 	}
@@ -53,18 +53,14 @@ signal_alarm(int sig) {
 static void
 signal_exit(int sig) {
 	exiting=1;
-	if (opt_d) {
-		output_line(0,"Received interrupt signal; exiting...");
-	}
+	debug(1,"Received interrupt signal; exiting...");
 	signal(SIGINT,SIG_IGN);
 	signal(SIGTERM,SIG_IGN);
 	signal(SIGALRM,signal_alarm);
 	if (opt_p) {
 		struct opt_p_t * tmp = opt_p;
 		while(tmp) {
-			if (opt_d>1) {
-				output_line(0,"Sending SIGSTOP to process %u\n",tmp->pid);
-			}
+			debug(2,"Sending SIGSTOP to process %u\n",tmp->pid);
 			kill(tmp->pid, SIGSTOP);
 			tmp = tmp->next;
 		}
@@ -75,6 +71,28 @@ signal_exit(int sig) {
 static void
 normal_exit(void) {
 	output_line(0,0);
+	if (opt_c) {
+		show_summary();
+	}
+}
+
+static void
+guess_cols(void) {
+	struct winsize ws;
+	char * c;
+
+	opt_a = DEFAULT_ACOLUMN;
+	c = getenv("COLUMNS");
+	if (c && *c) {
+		char * endptr;
+		int cols;
+		cols = strtol(c, &endptr, 0);
+		if (cols>0 && !*endptr) {
+			opt_a = cols * 5/8;
+		}
+	} else if (ioctl(1, TIOCGWINSZ, &ws) != -1 && ws.ws_col>0) {
+		opt_a = ws.ws_col * 5/8;
+	}
 }
 
 int
@@ -86,6 +104,7 @@ main(int argc, char **argv) {
 	signal(SIGINT,signal_exit);	/* Detach processes when interrupted */
 	signal(SIGTERM,signal_exit);	/*  ... or killed */
 
+	guess_cols();
 	argv = process_options(argc, argv);
 	read_config_file(SYSCONFDIR "/ltrace.conf");
 	home = getenv("HOME");
@@ -99,10 +118,10 @@ main(int argc, char **argv) {
 		strcat(path, "/.ltrace.conf");
 		read_config_file(path);
 	}
-	if (opt_d && opt_e) {
+	if (opt_e) {
 		struct opt_e_t * tmp = opt_e;
 		while(tmp) {
-			printf("Option -e: %s\n", tmp->name);
+			debug(1,"Option -e: %s\n", tmp->name);
 			tmp = tmp->next;
 		}
 	}
