@@ -28,6 +28,10 @@
 # define PTRACE_POKEUSER PTRACE_POKEUSR
 #endif
 
+void
+get_arch_dep(struct process * proc) {
+}
+
 /* Returns 1 if syscall, 2 if sysret, 0 otherwise.
  */
 int
@@ -86,3 +90,7 @@ gimme_arg(enum tof type, struct process * proc, int arg_num) {
 				exit(2);
 	}
 }
+
+void
+save_register_args(enum tof type, struct process * proc) {
+}
